==> weixin-api-1.0.1-sources.jar: com/jiamai/weixin/bean/message/templatemessage/WxOpenSubscribeMessage.java <==
package com.jiamai.weixin.bean.message.templatemessage;

import java.util.LinkedHashMap;

public class WxOpenSubscribeMessage {

	/**
	 * 接收者（用户）的 openid
	 */
	private String touser;

	/**
	 * 所需下发的订阅模板id
	 */
	private String template_id;

	/**
	 * 点击模板卡片后的跳转页面，仅限本小程序内的页面。支持带参数,（示例index?foo=bar）。该字段不填则模板无跳转。
	 */
	private String page;

	/**
	 * 跳转小程序类型：developer为开发版；trial为体验版；formal为正式版；默认为正式版
	 */
	private String miniprogram_state;

	/**
	 * 进入小程序查看”的语言类型，支持zh_CN(简体中文)、en_US(英文)、zh_HK(繁体中文)、zh_TW(繁体中文)，默认为zh_CN 返回值
	 */
	private String lang;

	private String emphasis_keyword;

	private LinkedHashMap<String, TemplateMessageItem> data;

	public String getPage() {
		return page;
	}

	public void setPage(String page) {
		this.page = page;
	}

	public String getTouser() {
		return touser;
	}

	public void setTouser(String touser) {
		this.touser = touser;
	}

	public String getTemplate_id() {
		return template_id;
	}

	public void setTemplate_id(String template_id) {
		this.template_id = template_id;
	}

	public String getMiniprogram_state() {
		return miniprogram_state;
	}

	public void setMiniprogram_state(String miniprogram_state) {
		this.miniprogram_state = miniprogram_state;
	}

	public String getLang() {
		return lang;
	}

	public void setLang(String lang) {
		this.lang = lang;
	}

	public String getEmphasis_keyword() {
		return emphasis_keyword;
	}

	public void setEmphasis_keyword(String emphasis_keyword) {
		this.emphasis_keyword = emphasis_keyword;
	}

	public LinkedHashMap<String, TemplateMessageItem> getData() {
		return data;
	}

	public void setData(LinkedHashMap<String, TemplateMessageItem> data) {
		this.data = data;
	}

}

==> weixin-api-1.0.5-sources.jar: com/jiamai/weixin/bean/message/templatemessage/WxOpenSubscribeMessage.java <==
package com.jiamai.weixin.bean.message.templatemessage;

import java.io.Serializable;
import java.util.LinkedHashMap;

public class WxOpenSubscribeMessage implements Serializable {

	private static final long serialVersionUID = 5772124003001703289L;

	/**
	 * 接收者（用户）的 openid
	 */
	private String touser;

	/**
	 * 所需下发的订阅模板id
	 */
	private String template_id;

	/**
	 * 点击模板卡片后的跳转页面，仅限本小程序内的页面。支持带参数,（示例index?foo=bar）。该字段不填则模板无跳转。
	 */
	private String page;

	/**
	 * 跳转小程序类型：developer为开发版；trial为体验版；formal为正式版；默认为正式版
	 */
	private String miniprogram_state;

	/**
	 * 进入小程序查看”的语言类型，支持zh_CN(简体中文)、en_US(英文)、zh_HK(繁体中文)、zh_TW(繁体中文)，默认为zh_CN 返回值
	 */
	private String lang;

	private String emphasis_keyword;

	private LinkedHashMap<String, TemplateMessageItem> data;

	public String getPage() {
		return page;
	}

	public void setPage(String page) {
		this.page = page;
	}

	public String getTouser() {
		return touser;
	}

	public void setTouser(String touser) {
		this.touser = touser;
	}

	public String getTemplate_id() {
		return template_id;
	}

	public void setTemplate_id(String template_id) {
		this.template_id = template_id;
	}

	public String getMiniprogram_state() {
		return miniprogram_state;
	}

	public void setMiniprogram_state(String miniprogram_state) {
		this.miniprogram_state = miniprogram_state;
	}

	public String getLang() {
		return lang;
	}

	public void setLang(String lang) {
		this.lang = lang;
	}

	public String getEmphasis_keyword() {
		return emphasis_keyword;
	}

	public void setEmphasis_keyword(String emphasis_keyword) {
		this.emphasis_keyword = emphasis_keyword;
	}

	public LinkedHashMap<String, TemplateMessageItem> getData() {
		return data;
	}

	public void setData(LinkedHashMap<String, TemplateMessageItem> data) {
		this.data = data;
	}

}
